# AMQP RPC Server
![PyLint](https://img.shields.io/github/workflow/status/j-suchard/amqp-rpc-server/Pylint?label=Pylint&logo=Python&logoColor=white)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/j-suchard/amqp-rpc-server/OSSAR?label=OSSAR&logo=GitHub)
![GitHub Workflow Status](https://img.shields.io/github/workflow/status/j-suchard/amqp-rpc-server/CodeQL?label=CodeQL&logo=GitHub)
![LicenseInformation](https://img.shields.io/github/license/j-suchard/amqp-rpc-server)

![PackageVersion](https://img.shields.io/pypi/v/amqp-rpc-server)
![SupportedPythonVersions](https://img.shields.io/pypi/pyversions/amqp-rpc-server?logo=python&logoColor=white)
<hr/>


This library offers a Remote-Procedure-Call server which gets its commands via 
a message broker which uses the AMQPv0-9-1 protocol.

Documentation: [https://j-suchard.github.io/amqp-rpc-server](https://j-suchard.github.io/amqp-rpc-server)  
GitHub Repository: [https://github.com/j-suchard/amqp-rpc-server](https://github.com/j-suchard/amqp-rpc-server)
